:mod:`art.defences.detector.evasion.subsetscanning`
===================================================
.. automodule:: art.defences.detector.evasion.subsetscanning

Subset Scanning Detector
------------------------
.. autoclass:: SubsetScanningDetector
   :members:
